/* 
 * Copyright (C) 2022.
 *
 * Centro de Gestion Informatica
 * Direccion de Tecnologias de la Informacion y Comunicacion
 * Universidad Nacional - Costa Rica
 * http://www.una.ac.cr
 * 
 */
/**
 * Author:  Gustavo Matamoros González
 * Created: 01/10/2022
 */

/********************************************************/
/********************************************************/
/* ELIMINAR LA VISTA                                    */
/********************************************************/
/********************************************************/
DROP PUBLIC SYNONYM VISTA_CONSUL_PLAN_ESTRATEGICO;

DROP VIEW PPI.VISTA_CONSUL_PLAN_ESTRATEGICO ;


/********************************************************/
/********************************************************/
/* DOCUMENTACIÓN DE LA VISTA                            */
/********************************************************/
/********************************************************/
/*
FUNCIÓN: Obtener la información de los planes de aportes y acciones estrategicas, por 
*/

--T1:   PPI.DETALLE_PLP
--T2:   PPI.EJE_ESTRATEGICO_PLP
--T3:   PPI.OBJETIVO_ESTRATEGICO_PLP
--T4:   PPI.DETALLE_PLP_EJE_TRANSVERSAL
--T5:   PPI.EJE_TRANSVERSAL_PLP
--T6:   TABLA TMP (JOIN) PARA EJES_TRANSVERSALES
--T7:   PPI.DETALLE_PMP
--T8:   PPI.PRIORIDAD_ESTRATEGICA_PMP
--T9:   PPI.OBJETIVO_ESTRATEGICO_PMP
--T10:  PPI.META_PMP
--T11:  PPI.AMBITO_ACCION_UNIVERSITARIA
--T12:  PPI.ACCION_ESTRATEGICA
--T13:  PPI.PLAN_ACCION_ESTRATEGICA
--T14:  EPF.UNIDAD_EJECUTORA (ACCION)
--T15:  PPI.APORTE_ESTRATEGICO
--T16:  PPI.PLAN_APORTE_ESTRATEGICO
--T17:  EPF.UNIDAD_EJECUTORA (APORTE)



/********************************************************/
/********************************************************/
/* CREACIÓN DE LA VISTA                                 */
/********************************************************/
/********************************************************/

CREATE OR REPLACE FORCE EDITIONABLE VIEW  PPI.VISTA_CONSUL_PLAN_ESTRATEGICO 

AS

SELECT 

    rownum AS ID,
    
    /* EJE_ESTRATEGICO_PLP */
    T2.CODIGO || '. ' || T2.DESCRIPCION AS EJE_ESTRATEGICO_PLP,
    
    /*OBJETIVO ESTRATEGICO PLP*/
    T3.CODIGO || '. ' || T3.DESCRIPCION AS OBJETIVO_ESTRATEGICO_PLP,
    
    /* EJES TRANSVERSALES_PLP */
    T6.EJES_TRANSVERSALES AS EJES_TRANSVERSALES_PLP,
    
    
    /* PRIORIDAD_ESTRATEGICA_PMP */
    T8.CODIGO || '. ' || T8.DESCRIPCION AS PRIORIDAD_ESTRATEGICA_PMP,

    /* OBJETIVO_ESTRATEGICO_PMP */
    T9.CODIGO || '. ' || T9.DESCRIPCION AS OBJETIVO_ESTRATEGICO_PMP,
    
    /* META_PMP */
    T10.CODIGO || '. ' || T10.DESCRIPCION AS META_PMP,   
    
    /* AMBITO_ACCION_UNIVERSITARIA */
    T11.NOMBRE AS AMBITO_ACCION_UNIVERSITARIA,
    
    /* ACCION_ESTRATEGICA_PMP */
    T12.CODIGO || '. ' || T12.DESCRIPCION AS ACCION_ESTRATEGICA_PMP,
    
    /* UNIDAD_EJECUTORA_ACCION_PMP */
    T14.CODIGO || '. ' || T14.NOMBRE  AS UNIDAD_EJECUTORA_ACCION_PMP, 
    
    /* APORTE_ESTRATEGICO_PMP */
    T15.CODIGO || '. ' || T15.DESCRIPCION AS APORTE_ESTRATEGICO_PMP,
    
    /* UNIDAD_EJECUTORA_APORTE_PMP */
    T17.CODIGO || '. ' || T17.NOMBRE  AS UNIDAD_EJECUTORA_APORTE_PMP
    
FROM PPI.DETALLE_PLP  T1

INNER JOIN PPI.EJE_ESTRATEGICO_PLP              T2      ON  (T2.ID_EJE_ESTRATEGICO_PLP          =       T1.EJE_ESTRATEGICO_PLP)
INNER JOIN PPI.OBJETIVO_ESTRATEGICO_PLP         T3      ON  (T3.ID_OBJETIVO_ESTRATEGICO_PLP     =       T1.OBJETIVO_ESTRATEGICO_PLP)
INNER JOIN PPI.DETALLE_PMP                      T7      ON  (T7.EJE_ESTRATEGICO_LARGO_PLAZO     =       T2.ID_EJE_ESTRATEGICO_PLP)
INNER JOIN PPI.PRIORIDAD_ESTRATEGICA_PMP        T8      ON  (T8.ID_PRIORIDAD_ESTRATEGICA_PMP    =       T7.PRIORIDAD_ESTRATEGICA_PMP)
INNER JOIN PPI.OBJETIVO_ESTRATEGICO_PMP         T9      ON  (T9.ID_OBJETIVO_ESTRATEGICO_PMP     =       T7.OBJETIVO_ESTRATEGICO_PMP)
INNER JOIN PPI.META_PMP                         T10     ON  (T10.DETALLE_PMP                    =       T7.ID_DETALLE_PMP)
INNER JOIN PPI.AMBITO_ACCION_UNIVERSITARIA      T11     ON  (T11.ID_AMBITO_ACCION_UNIVERSITARIA =       T10.AMBITO_ACCION_UNIVERSITARIA)


INNER JOIN PPI.ACCION_ESTRATEGICA               T12     ON  (T12.AMBITO_ACCION_UNIVERSITARIA    =       T11.ID_AMBITO_ACCION_UNIVERSITARIA)
INNER JOIN PPI.PLAN_ACCION_ESTRATEGICA          T13     ON  (T13.ID_PLAN_ACCION_ESTRATEGICA     =       T12.PLAN_ACCION_ESTRATEGICA)
INNER JOIN EPF.UNIDAD_EJECUTORA                 T14     ON  (T14.ID_UNIDAD_EJECUTORA            =       T13.UNIDAD_EJECUTORA)
INNER JOIN PPI.APORTE_ESTRATEGICO               T15     ON  (T15.ACCION_ESTRATEGICA             =       T12.ID_ACCION_ESTRATEGICA)
INNER JOIN PPI.PLAN_APORTE_ESTRATEGICO          T16     ON  (T16.ID_PLAN_APORTE_ESTRATEGICO     =       T15.PLAN_APORTE_ESTRATEGICO)
INNER JOIN EPF.UNIDAD_EJECUTORA                 T17     ON  (T17.ID_UNIDAD_EJECUTORA            =       T16.UNIDAD_EJECUTORA)

JOIN
(
SELECT 
        DISTINCT T4.DETALLE_PLP AS DETPLP,
        RTRIM(XMLAGG(XMLELEMENT(E, T5.CODIGO ||'. '|| T5.DESCRIPCION || ' ', CHR(10) || CHR(13)).EXTRACT('//text()') ORDER BY T5.CODIGO).GETCLOBVAL(),',') AS EJES_TRANSVERSALES
        FROM PPI.DETALLE_PLP_EJE_TRANSVERSAL T4
        LEFT JOIN PPI.EJE_TRANSVERSAL_PLP T5 ON (T5.ID_EJE_TRANSVERSAL_PLP = T4.EJE_TRANSVERSAL_PLP)
        GROUP BY T4.DETALLE_PLP
) T6 ON T6.DETPLP = T1.ID_DETALLE_PLP
WHERE 

--PPI.ACCION_ESTRATEGICA.META_PMP = PPI.META_PMP.ID_META_PMP
(T12.META_PMP = T10.ID_META_PMP)


--PPI.PLAN_APORTE_ESTRATEGICO.ACTIVO=1
AND
(T16.ACTIVO = 1)


--PPI.PLAN_ACCION_ESTRATEGICA.ACTIVO=1
AND
(T13.ACTIVO = 1)


--PPI.PLAN_APORTE_ESTRATEGICO.ESTADO_FORMULACION_PAE=5 (COMPLETADO)
AND
(T16.ESTADO_FORMULACION_PAE = (SELECT VALOR FROM SAS.PARAMETRO
WHERE LLAVE = 'param_ppi_ppe_estadoFormulacionPAE_aprobado'))

ORDER BY T2.ID_EJE_ESTRATEGICO_PLP,T3.ID_OBJETIVO_ESTRATEGICO_PLP;


/********************************************************/
/********************************************************/
/* CREACIÓN DE SINONIMO                                 */
/********************************************************/
/********************************************************/
CREATE PUBLIC SYNONYM VISTA_CONSUL_PLAN_ESTRATEGICO for PPI.VISTA_CONSUL_PLAN_ESTRATEGICO;


/********************************************************/
/********************************************************/
/* GRANT'S                                              */
/********************************************************/
/********************************************************/
GRANT SELECT, REFERENCES ON PPI.VISTA_CONSUL_PLAN_ESTRATEGICO TO SAS;
GRANT SELECT, REFERENCES ON PPI.VISTA_CONSUL_PLAN_ESTRATEGICO TO EPF;


GRANT select, references ON EPF.UNIDAD_EJECUTORA TO PPI WITH GRANT OPTION;
GRANT select, references ON SAS.PARAMETRO TO PPI WITH GRANT OPTION;


GRANT DELETE, INSERT, UPDATE, SELECT, REFERENCES on PPI.VISTA_CONSUL_PLAN_ESTRATEGICO
to "WWW_SIGESA";


GRANT SELECT, DELETE, UPDATE, INSERT ON PPI.VISTA_CONSUL_PLAN_ESTRATEGICO TO WWW_SIGESA, WWW_TEUNA;
GRANT SELECT, ALTER ON PPI.VISTA_CONSUL_PLAN_ESTRATEGICO TO WWW_SIGESA, WWW_TEUNA;
GRANT SELECT ON PPI.VISTA_CONSUL_PLAN_ESTRATEGICO TO "ANALISTA", "ANALISTA_SIGESA";


SELECT * FROM VISTA_CONSUL_PLAN_ESTRATEGICO;

SELECT * FROM SAS.I18N WHERE LLAVE LIKE '%vistaPlanEstrategico%';
